#' World map in Geojson format (list)
#' 
#' This data comes from the \url{https://code.highcharts.com/mapdata/custom/world.js}
#' and is used in highmaps examples.#'
#'
#' @docType data
#' @name worldgeojson
#' @usage worldgeojson
#' @format A \code{list} in geojson format.
"worldgeojson"
